AndroidEqualizerBandMessage class

Information about an equalizer band to be communicated with the platform implementation.

Constructors

AndroidEqualizerBandMessage({required int index, required double lowerFrequency, required double upperFrequency, required double centerFrequency, required double gain})

Properties

centerFrequency → double
The center frequency of this band in hertz.
final
gain → double
The gain for this band in decibels.
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A zero-based index of the position of this band within its AndroidEqualizer.
final
lowerFrequency → double
The lower frequency of this band in hertz.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upperFrequency → double
The upper frequency of this band in hertz.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → AndroidEqualizerBandMessage