AndroidEqualizerMessage class

Information about the equalizer to be communicated with the platform implementation.

Inheritance

Constructors

AndroidEqualizerMessage({required bool enabled, required AndroidEqualizerParametersMessage? parameters})

Properties

enabled → bool
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
parameters → AndroidEqualizerParametersMessage?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited