AndroidLivePlaybackSpeedControlMessage class

Constructors

AndroidLivePlaybackSpeedControlMessage({required double fallbackMinPlaybackSpeed, required double fallbackMaxPlaybackSpeed, required Duration minUpdateInterval, required double proportionalControlFactor, required Duration maxLiveOffsetErrorForUnitSpeed, required Duration targetLiveOffsetIncrementOnRebuffer, required double minPossibleLiveOffsetSmoothingFactor})

Properties

fallbackMaxPlaybackSpeed → double
(Android) The maximum playback speed to use when adjusting playback speed to approach the target live offset, if none is defined by the media.
final
fallbackMinPlaybackSpeed → double
(Android) The minimum playback speed to use when adjusting playback speed to approach the target live offset, if none is defined by the media.
final
hashCode → int
The hash code for this object.
no setterinherited
maxLiveOffsetErrorForUnitSpeed → Duration
(Android) The maximum difference between the current live offset and the target live offset within which the speed 1.0 is used.
final
minPossibleLiveOffsetSmoothingFactor → double
(Android) The factor for smoothing the minimum possible live offset achievable during playback.
final
minUpdateInterval → Duration
(Android) The minimum interval between playback speed changes on a live stream.
final
proportionalControlFactor → double
(Android) The proportional control factor used to adjust playback speed on a live stream. The adjusted speed is calculated as: 1.0 + proportionalControlFactor * (currentLiveOffsetSec - targetLiveOffsetSec).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetLiveOffsetIncrementOnRebuffer → Duration
(Android) The increment applied to the target live offset whenever the player rebuffers.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited