AndroidLoadControlMessage class

Constructors

AndroidLoadControlMessage({required Duration minBufferDuration, required Duration maxBufferDuration, required Duration bufferForPlaybackDuration, required Duration bufferForPlaybackAfterRebufferDuration, required int? targetBufferBytes, required bool prioritizeTimeOverSizeThresholds, required Duration backBufferDuration})

Properties

backBufferDuration → Duration
(Android) The back buffer duration.
final
bufferForPlaybackAfterRebufferDuration → Duration
(Android) The duration of audio that must be buffered before starting playback after a buffer depletion.
final
bufferForPlaybackDuration → Duration
(Android) The duration of audio that must be buffered before starting playback after a user action.
final
hashCode → int
The hash code for this object.
no setterinherited
maxBufferDuration → Duration
(Android) The maximum duration of audio that should be buffered ahead of the current position.
final
minBufferDuration → Duration
(Android) The minimum duration of audio that should be buffered ahead of the current position.
final
prioritizeTimeOverSizeThresholds → bool
(Android) Whether to prioritize buffer time constraints over buffer size constraints.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetBufferBytes → int?
(Android) The target buffer size in bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited