ConcatenatingMoveRequest class

Information communicated to the platform implementation when moving an audio source within a concatenating audio source.

Constructors

ConcatenatingMoveRequest({required String id, required int currentIndex, required int newIndex, required List<int> shuffleOrder})

Properties

currentIndex → int
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
newIndex → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shuffleOrder → List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited