ConcatenatingRemoveRangeRequest class

Information communicated to the platform implementation when removing audio sources from a concatenating audio source.

Constructors

ConcatenatingRemoveRangeRequest({required String id, required int startIndex, required int endIndex, required List<int> shuffleOrder})

Properties

endIndex → int
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shuffleOrder → List<int>
final
startIndex → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited