DarwinLoadControlMessage class

Constructors

DarwinLoadControlMessage({required bool automaticallyWaitsToMinimizeStalling, required Duration? preferredForwardBufferDuration, required bool canUseNetworkResourcesForLiveStreamingWhilePaused, required double? preferredPeakBitRate})

Properties

automaticallyWaitsToMinimizeStalling → bool
(iOS/macOS) Whether the player will wait for sufficient data to be buffered before starting playback to avoid the likelihood of stalling.
final
canUseNetworkResourcesForLiveStreamingWhilePaused → bool
(iOS/macOS) Whether the player can continue downloading while paused to keep the state up to date with the live stream.
final
hashCode → int
The hash code for this object.
no setterinherited
preferredForwardBufferDuration → Duration?
(iOS/macOS) The duration of audio that should be buffered ahead of the current position. If not set or null, the system will try to set an appropriate buffer duration.
final
preferredPeakBitRate → double?
(iOS/macOS) If specified, limits the download bandwidth in bits per second.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited