ProgressiveAudioSourceMessage class

Information about a progressive audio source to be communicated with the platform implementation.

Inheritance

Constructors

ProgressiveAudioSourceMessage({required String id, required String uri, Map<String, String>? headers, dynamic tag})

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
finalinherited
id → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → dynamic
Since the tag type is unknown, this can only be used by platform implementations that pass by reference.
finalinherited
uri → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited