SetShuffleModeRequest class

Information communicated to the platform implementation when setting the shuffle mode.

Constructors

SetShuffleModeRequest({required ShuffleModeMessage shuffleMode})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shuffleMode → ShuffleModeMessage
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited