StartVisualizerRequest class

Information communicated to the platform implementation when starting the visualizer.

Constructors

StartVisualizerRequest({required bool enableWaveform, required bool enableFft, required int? captureRate, required int? captureSize})

Properties

captureRate → int?
final
captureSize → int?
final
enableFft → bool
final
enableWaveform → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited